@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,10 +11,12 @@
 class QUrl;
 class QAbstractButton;
 
-namespace Ui {
+namespace Ui
+{
 class SelectThunderbirdFilterFilesWidget;
 }
-namespace MailCommon {
+namespace MailCommon
+{
 class SelectThunderbirdFilterFilesWidget : public QWidget
 {
     Q_OBJECT
