@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,11 +9,13 @@
 
 #include "interfaces/rulewidgethandler.h"
 
-namespace MailCommon {
+namespace MailCommon
+{
 class TagRuleWidgetHandler : public MailCommon::RuleWidgetHandler
 {
 public:
-    TagRuleWidgetHandler() : MailCommon::RuleWidgetHandler()
+    TagRuleWidgetHandler()
+        : MailCommon::RuleWidgetHandler()
     {
     }
 
