@@ -1,23 +1,23 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "snippetattachmentwidget.h"
 #include "snippetselectattachmentdialog.h"
+#include <KLocalizedString>
 #include <QHBoxLayout>
 #include <QLineEdit>
-#include <KLocalizedString>
-#include <QToolButton>
 #include <QPointer>
+#include <QToolButton>
 
 using namespace MailCommon;
 
 SnippetAttachmentWidget::SnippetAttachmentWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *layout = new QHBoxLayout(this);
+    auto layout = new QHBoxLayout(this);
     layout->setObjectName(QStringLiteral("layout"));
     layout->setContentsMargins(0, 0, 0, 0);
 
@@ -27,7 +27,7 @@ SnippetAttachmentWidget::SnippetAttachmentWidget(QWidget *parent)
     layout->addWidget(mLineEdit);
     mLineEdit->setReadOnly(true);
 
-    auto *button = new QToolButton(this);
+    auto button = new QToolButton(this);
     button->setObjectName(QStringLiteral("button"));
     button->setToolTip(i18n("Select Attachments"));
     button->setText(i18n("..."));
@@ -57,11 +57,7 @@ void SnippetAttachmentWidget::clear()
 void SnippetAttachmentWidget::slotSelectAttachment()
 {
     QPointer<MailCommon::SnippetSelectAttachmentDialog> dlg = new MailCommon::SnippetSelectAttachmentDialog(this);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    dlg->setAttachments(mLineEdit->text().split(QLatin1Char(','), QString::SkipEmptyParts));
-#else
     dlg->setAttachments(mLineEdit->text().split(QLatin1Char(','), Qt::SkipEmptyParts));
-#endif
     if (dlg->exec()) {
         mLineEdit->setText(dlg->attachments().join(QLatin1Char(',')));
         Q_EMIT wasChanged();
