@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -7,18 +7,19 @@
 #ifndef SNIPPETATTACHMENTWIDGET_H
 #define SNIPPETATTACHMENTWIDGET_H
 
-#include <QWidget>
 #include "mailcommon_private_export.h"
+#include <QWidget>
 
 class QLineEdit;
 
-namespace MailCommon {
+namespace MailCommon
+{
 class MAILCOMMON_TESTS_EXPORT SnippetAttachmentWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit SnippetAttachmentWidget(QWidget *parent = nullptr);
-    ~SnippetAttachmentWidget();
+    ~SnippetAttachmentWidget() override;
     void setText(const QString &str);
     Q_REQUIRED_RESULT QString text() const;
     void clear();
