@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -8,22 +8,22 @@
 #include "redirectwidget.h"
 #include "kernel/mailkernel.h"
 
-#include <QTreeView>
 #include <MessageComposer/ComposerLineEdit>
+#include <QTreeView>
 
 #include <Akonadi/Contact/EmailAddressSelectionDialog>
 
-#include <QIcon>
-#include <QHBoxLayout>
-#include <QPushButton>
 #include <KLocalizedString>
+#include <QHBoxLayout>
+#include <QIcon>
+#include <QPushButton>
 
 using namespace MailCommon;
 
 RedirectWidget::RedirectWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *hbox = new QHBoxLayout(this);
+    auto hbox = new QHBoxLayout(this);
     hbox->setSpacing(0);
     hbox->setContentsMargins(0, 0, 0, 0);
     hbox->setAlignment(Qt::AlignRight);
@@ -34,12 +34,13 @@ RedirectWidget::RedirectWidget(QWidget *parent)
     mEdit->setClearButtonEnabled(true);
     hbox->addWidget(mEdit);
 
-    auto *BtnTo = new QPushButton(this);
+    auto BtnTo = new QPushButton(this);
     BtnTo->setIcon(QIcon::fromTheme(QStringLiteral("help-contents")));
     BtnTo->setToolTip(i18n("Use the Address-Selection Dialog"));
-    BtnTo->setWhatsThis(i18n("This button opens a separate dialog "
-                             "where you can select recipients out "
-                             "of all available addresses."));
+    BtnTo->setWhatsThis(
+        i18n("This button opens a separate dialog "
+             "where you can select recipients out "
+             "of all available addresses."));
     hbox->addWidget(BtnTo);
     connect(BtnTo, &QAbstractButton::clicked, this, &RedirectWidget::slotAddressSelection);
 
@@ -66,8 +67,7 @@ void RedirectWidget::setFocus()
 
 void RedirectWidget::slotAddressSelection()
 {
-    std::unique_ptr<Akonadi::EmailAddressSelectionDialog> dlg(
-        new Akonadi::EmailAddressSelectionDialog(this));
+    std::unique_ptr<Akonadi::EmailAddressSelectionDialog> dlg(new Akonadi::EmailAddressSelectionDialog(this));
 
     dlg->view()->view()->setSelectionMode(QAbstractItemView::MultiSelection);
 
